# biome.text API reference
Here you can find the API reference of the `biome.text` library.

Use the left-side bar to navigate through the library API or the search bar to find specific modules, classes and methods.

